var NAVTREEINDEX7 =
{
"group__API__MPI__Support.html#gaaf806ce3131edd757470c7401bd41bd7":[57,23,14],
"group__API__MPI__Support.html#gab1cdef357b93d4f9f332199da819b792":[57,23,37],
"group__API__MPI__Support.html#gab29d3615c578d9d2cf27929bfc23765a":[57,23,56],
"group__API__MPI__Support.html#gab69b1f823043d16b7d0d799d1ad88a04":[57,23,95],
"group__API__MPI__Support.html#gab9a3f9061a971460a0d2935460a184f6":[57,23,3],
"group__API__MPI__Support.html#gab9aa0041da79711be2440613d2a9cfcc":[57,23,59],
"group__API__MPI__Support.html#gabb4f38872a0b5fd8122b681acc0cf932":[57,23,54],
"group__API__MPI__Support.html#gabdb1e15d1fc805115d660848a711f101":[57,23,20],
"group__API__MPI__Support.html#gabefad62cd0f0ea270a95e97c0fae17d6":[57,23,2],
"group__API__MPI__Support.html#gabf6f5ee9cf18ad1ac5b277268d29328d":[57,23,77],
"group__API__MPI__Support.html#gabfd3536dd43a94d59be008143a2cc5d4":[57,23,45],
"group__API__MPI__Support.html#gac0f4230d1b2e6e112dac80e55c05a557":[57,23,110],
"group__API__MPI__Support.html#gac4edc30de38dcb51bd7ba7d1b57dc6c0":[57,23,86],
"group__API__MPI__Support.html#gacb05635d95f946f099a1772c8bd59c8b":[57,23,69],
"group__API__MPI__Support.html#gad477e38cca08eba443c47bece0f76831":[57,23,107],
"group__API__MPI__Support.html#gad6453ef7697756dd3b1746399eec4867":[57,23,96],
"group__API__MPI__Support.html#gad76d4345fb7f6576edc3d81e07f63646":[57,23,100],
"group__API__MPI__Support.html#gadc9112873f348b1f6daa0da4b93b061f":[57,23,5],
"group__API__MPI__Support.html#gadce715a49b477ef0204be1a199abfddb":[57,23,12],
"group__API__MPI__Support.html#gadd2fd077198e6938baf63ae788f6941a":[57,23,6],
"group__API__MPI__Support.html#gadebfc49849af7601e10740f7eebff6a1":[57,23,105],
"group__API__MPI__Support.html#gadf1f289d1cf35bd31df930bc347fb9ce":[57,23,70],
"group__API__MPI__Support.html#gadfcd5ec8bffb9c5711ad6756e8f7419b":[57,23,1],
"group__API__MPI__Support.html#gae35cb568f1a1fff5afeb356e68f828f8":[57,23,111],
"group__API__MPI__Support.html#gae8e8389eb3e916131946028e9ebee670":[57,23,52],
"group__API__MPI__Support.html#gaea1d834d6afcf6bd9419ee363ace2ff5":[57,23,31],
"group__API__MPI__Support.html#gaea43295cdbe0b97c3d270362f73fad14":[57,23,29],
"group__API__MPI__Support.html#gaea541932f03aefeba62b7f123d9a941b":[57,23,113],
"group__API__MPI__Support.html#gaebb931d03782a5b77a5bf3f6df3bf3f7":[57,23,93],
"group__API__MPI__Support.html#gaebee3997a7ee6db5e3cedcc0cbc2a6c8":[57,23,112],
"group__API__MPI__Support.html#gaec31509b00ac2234fc9e8601e6d3e924":[57,23,39],
"group__API__MPI__Support.html#gaec408170d2c815fdfdafa24873bc02da":[57,23,19],
"group__API__MPI__Support.html#gaee6045677d02bc11f83cf00c723562b3":[57,23,72],
"group__API__MPI__Support.html#gaf003d1f0f6882cc65135efb950cadb9f":[57,23,40],
"group__API__MPI__Support.html#gaf420b44479ae98b774be21a52c0ab931":[57,23,75],
"group__API__MPI__Support.html#gaf51498eeaa97e09b9f1248b3e21d5e9c":[57,23,36],
"group__API__MPI__Support.html#gaf83405a3154137f00ccf554c5e5684b5":[57,23,104],
"group__API__MPI__Support.html#gaf892316a619d2dd9a009e87fee3b40b5":[57,23,106],
"group__API__MPI__Support.html#gaf9345fd74fd060cc6712457e711b29c1":[57,23,61],
"group__API__MPI__Support.html#gafcf6f76ebbfe21c54cbece6b17777c85":[57,23,58],
"group__API__MPI__Support.html#gaffbf339d154f76faa0061467b47cb1d1":[57,23,63],
"group__API__MPI__Support.html#structstarpu__mpi__task__exchange__params":[57,23,0],
"group__API__Max__FPGA__Extensions.html":[57,13],
"group__API__Max__FPGA__Extensions.html#a2cf83f64b309bdafcc1f30691b660d88":[57,13,0,0],
"group__API__Max__FPGA__Extensions.html#a7c29ba6b31ef6459b19e9ab0461b828c":[57,13,0,1],
"group__API__Max__FPGA__Extensions.html#ga6dfcf82c7b941a50a9bc2e478dfc4897":[57,13,1],
"group__API__Max__FPGA__Extensions.html#ga7f7a92414ff1a98d7523bc40f36d0878":[57,13,2],
"group__API__Max__FPGA__Extensions.html#gaab45e70c85fc1786d6d5e618fd5c3922":[57,13,3],
"group__API__Max__FPGA__Extensions.html#structstarpu__max__load":[57,13,0],
"group__API__Miscellaneous__Helpers.html":[57,33],
"group__API__Miscellaneous__Helpers.html#ga090e97b588f83718c19f0ed3d07d1d70":[57,33,14],
"group__API__Miscellaneous__Helpers.html#ga0e762c057c5206bd093534e5dd145b1c":[57,33,17],
"group__API__Miscellaneous__Helpers.html#ga127022a5dde360045b603e47a5faf303":[57,33,20],
"group__API__Miscellaneous__Helpers.html#ga205dc8faae407fe2c524968badf99fef":[57,33,10],
"group__API__Miscellaneous__Helpers.html#ga30a209003955a8e4d528a3efa224a7d8":[57,33,19],
"group__API__Miscellaneous__Helpers.html#ga34953348991f74a1cbd694fffb27f8b7":[57,33,15],
"group__API__Miscellaneous__Helpers.html#ga418ebab6a2b90ff9b30720869b03f601":[57,33,5],
"group__API__Miscellaneous__Helpers.html#ga4668e2b610cbb2a3521e36d6f8ff9d1c":[57,33,21],
"group__API__Miscellaneous__Helpers.html#ga4c4f93f8ed79333f5801058af4267d84":[57,33,2],
"group__API__Miscellaneous__Helpers.html#ga77f0f3796a059b3651f7ecb4535dad82":[57,33,13],
"group__API__Miscellaneous__Helpers.html#ga7a97b0699b97b30b4d408c660be46102":[57,33,12],
"group__API__Miscellaneous__Helpers.html#ga986c62892d4ace00e36a44acae83f3ba":[57,33,18],
"group__API__Miscellaneous__Helpers.html#gaa05ae4c9a83191829ea3230c06329bb2":[57,33,9],
"group__API__Miscellaneous__Helpers.html#gaa156afa885bb447bc0ced3ea66bcf7e6":[57,33,1],
"group__API__Miscellaneous__Helpers.html#gaa9ce920cfe1fccd3e57932b6cdfac634":[57,33,4],
"group__API__Miscellaneous__Helpers.html#gaaff4ecf5818fd6f8d005f6bf57b0eb4b":[57,33,16],
"group__API__Miscellaneous__Helpers.html#gab4c1b68e62245662b1d02b2f8b65b596":[57,33,22],
"group__API__Miscellaneous__Helpers.html#gabaef4f5da94dd1c0e7d5c5e12155654b":[57,33,8],
"group__API__Miscellaneous__Helpers.html#gac7575c5106fb88dbee9f9e7b0a6b5c9c":[57,33,7],
"group__API__Miscellaneous__Helpers.html#gad58ce4f0bf091ee75415b1e379e7cf0f":[57,33,6],
"group__API__Miscellaneous__Helpers.html#gad614bcaae1a110a4ddc0ddc3636dac5d":[57,33,0],
"group__API__Miscellaneous__Helpers.html#gad8982cf38fad16a87ba4b474febf8a72":[57,33,11],
"group__API__Miscellaneous__Helpers.html#gae86951bac33515af402555de40612711":[57,33,3],
"group__API__Modularized__Scheduler.html":[57,18],
"group__API__Modularized__Scheduler.html#a00dad65a73e8a08c554b088fd02c62ac":[57,18,0,14],
"group__API__Modularized__Scheduler.html#a1573b03ce168859dcb85d8ceafa244a6":[57,18,0,1],
"group__API__Modularized__Scheduler.html#a2042f495e746d4ec1ac84c8eb6f5b37d":[57,18,0,3],
"group__API__Modularized__Scheduler.html#a22e788223ba09f3faf57859f8e0cfefc":[57,18,0,18],
"group__API__Modularized__Scheduler.html#a238bfb25ff26f489ab3f8f0c336192ca":[57,18,1,1],
"group__API__Modularized__Scheduler.html#a27af06d3f659a32cb4f3b9599fba00d8":[57,18,0,8],
"group__API__Modularized__Scheduler.html#a404381c9bd5c918e8e29ea1aae092067":[57,18,0,17],
"group__API__Modularized__Scheduler.html#a46c8e9094cfcc00e36c31d8e6feced59":[57,18,0,0],
"group__API__Modularized__Scheduler.html#a4c7d5c03e2acf93fa737540b35eb1001":[57,18,0,13],
"group__API__Modularized__Scheduler.html#a541135ecb60d398ac6b2d98c1a59fb2c":[57,18,0,7],
"group__API__Modularized__Scheduler.html#a59dedc6c07c0bcfd78639da0e4073d73":[57,18,7,3],
"group__API__Modularized__Scheduler.html#a5b27ab8642148517e8addec4863c2042":[57,18,1,0],
"group__API__Modularized__Scheduler.html#a5d4260fca364243f76305e6ea7a1a69f":[57,18,7,5],
"group__API__Modularized__Scheduler.html#a66b33bee46a8d853dd25ee16645cf673":[57,18,1,3],
"group__API__Modularized__Scheduler.html#a6979a86b074eb35903929f98272b2ab2":[57,18,0,5],
"group__API__Modularized__Scheduler.html#a6eb7354ca7f5b96634eec2bb44f14ae4":[57,18,0,9],
"group__API__Modularized__Scheduler.html#a783d5970fe203d01442fb32bc4cafb7c":[57,18,7,2],
"group__API__Modularized__Scheduler.html#a78d7ba588cf0d03007db07afc3d38bc3":[57,18,0,16],
"group__API__Modularized__Scheduler.html#a79f98f04b4efe58b32fe1ab4f244fe46":[57,18,1,2],
"group__API__Modularized__Scheduler.html#a86ea24c3238c3424b622496cbbd0bbd1":[57,18,0,15],
"group__API__Modularized__Scheduler.html#a8ad4510734e8daf414fa41799e276486":[57,18,0,11],
"group__API__Modularized__Scheduler.html#aa2e8258747cb3bb967fef0519d139579":[57,18,0,4],
"group__API__Modularized__Scheduler.html#aa989aab198005eff62cd799b02ded7cb":[57,18,0,10],
"group__API__Modularized__Scheduler.html#aae51d116f77022be95faa94e94861c52":[57,18,0,2],
"group__API__Modularized__Scheduler.html#aaeece58ba0e3476e9c66fdb31e71784b":[57,18,0,6],
"group__API__Modularized__Scheduler.html#ab9e0712a96a5431e872db511777a3ad3":[57,18,7,4],
"group__API__Modularized__Scheduler.html#abec52a111491d978567b509117607aa3":[57,18,7,0],
"group__API__Modularized__Scheduler.html#abf315d3c1f60fbcab6a001f7925dc4fa":[57,18,0,12],
"group__API__Modularized__Scheduler.html#ac2709f00c42977b8df96d30015fc9cb1":[57,18,0,19],
"group__API__Modularized__Scheduler.html#ad859296dbded64c8593d613286893a93":[57,18,7,1],
"group__API__Modularized__Scheduler.html#ga063bc22ea750afba5bebe22e3117258b":[57,18,25],
"group__API__Modularized__Scheduler.html#ga0b4db1194be324a7cbd2c6486db867d7":[57,18,73],
"group__API__Modularized__Scheduler.html#ga0c419ef90f6adce7cc9ebca955822dbb":[57,18,63],
"group__API__Modularized__Scheduler.html#ga0e50b97229fdf62b5006eba35f4d5683":[57,18,24],
"group__API__Modularized__Scheduler.html#ga12e7e5b58b9aebb4f3084fa807c55c40":[57,18,14],
"group__API__Modularized__Scheduler.html#ga1460e5ad34f360408b3a0003aa0a2b9f":[57,18,46],
"group__API__Modularized__Scheduler.html#ga17b2f48b9873e1a1b842bb81ed22e972":[57,18,62],
"group__API__Modularized__Scheduler.html#ga1fd3c2682a57ca9105965b942a5a1313":[57,18,47],
"group__API__Modularized__Scheduler.html#ga217b0c2bb96b4aa5f0ccda71c2d81f00":[57,18,42],
"group__API__Modularized__Scheduler.html#ga21df9bf6da463d3b945f0886939b637a":[57,18,49],
"group__API__Modularized__Scheduler.html#ga231e99e5ce0ecca11b8affebf40bdd9a":[57,18,65],
"group__API__Modularized__Scheduler.html#ga248d8a1f97615362cb60e78a7ffbf298":[57,18,71],
"group__API__Modularized__Scheduler.html#ga2a0aac2afe33c1ef0bf3260de25be29e":[57,18,36],
"group__API__Modularized__Scheduler.html#ga2f27b106110cf20f52ed20e68ecd8613":[57,18,75],
"group__API__Modularized__Scheduler.html#ga305b8f17f3d49897cebe8376aaede5a2":[57,18,48],
"group__API__Modularized__Scheduler.html#ga30b0cd3f3d64be88a163a31148c58f1f":[57,18,38],
"group__API__Modularized__Scheduler.html#ga3ac4da6a19d9f0a34e870e20d6c34966":[57,18,72],
"group__API__Modularized__Scheduler.html#ga3c60576fc0645bec4cd90c758545fd40":[57,18,76],
"group__API__Modularized__Scheduler.html#ga3f9c54f338cb39029b508f5890b1111a":[57,18,17],
"group__API__Modularized__Scheduler.html#ga424d5bae6d2c3c99ab4f215b0e23698f":[57,18,58],
"group__API__Modularized__Scheduler.html#ga478058eac115f3889d6f39273d66a53f":[57,18,30],
"group__API__Modularized__Scheduler.html#ga48a2bf7d22985f9a810f8a563153e936":[57,18,51],
"group__API__Modularized__Scheduler.html#ga49a5e198c16a141aee76be2416b7dbb4":[57,18,79],
"group__API__Modularized__Scheduler.html#ga4a02a60ffa8959fda08292dbf7aa20f7":[57,18,57],
"group__API__Modularized__Scheduler.html#ga4fd6f598c30dac693e9e5b37f3e450f6":[57,18,67],
"group__API__Modularized__Scheduler.html#ga502c075e94e2988007333d8f0f80b69c":[57,18,78],
"group__API__Modularized__Scheduler.html#ga511a8c5bc261cae8153cdfe7670a21a4":[57,18,33],
"group__API__Modularized__Scheduler.html#ga5c4ea8cd11d331eb39de2c02ce29efb1":[57,18,39],
"group__API__Modularized__Scheduler.html#ga61c2f443fb8d5b6a2a1404eae0e7868e":[57,18,31],
"group__API__Modularized__Scheduler.html#ga685a73facd82449b2f21f76f909e4ac3":[57,18,60],
"group__API__Modularized__Scheduler.html#ga686ebaecfc562cacc98b20bbb7db5ebf":[57,18,34],
"group__API__Modularized__Scheduler.html#ga699b31664bb3665f25ef360c2512d8f9":[57,18,59],
"group__API__Modularized__Scheduler.html#ga6b1f65158357aae0d9239063e54f82a4":[57,18,21],
"group__API__Modularized__Scheduler.html#ga70c74dee688684fb09e45833094ba21a":[57,18,27],
"group__API__Modularized__Scheduler.html#ga72554d14205573f57631b850afa3f39f":[57,18,11],
"group__API__Modularized__Scheduler.html#ga752889050651f6e3c83ddd2c3f96c0ff":[57,18,64],
"group__API__Modularized__Scheduler.html#ga782b27a1b864b0d21294f3d8da8756f8":[57,18,61],
"group__API__Modularized__Scheduler.html#ga79594b4403678fa1d6aa08f7fbe6e525":[57,18,45],
"group__API__Modularized__Scheduler.html#ga795d692f797ef022c350c9b5922cec31":[57,18,41],
"group__API__Modularized__Scheduler.html#ga7bacda898bdd7964b21ce611c7db077b":[57,18,10],
"group__API__Modularized__Scheduler.html#ga7ceaaeea8cc10f6d67706c4ee33e93ce":[57,18,37],
"group__API__Modularized__Scheduler.html#ga813c6be6ae07ec5fe6e54a1bd97267ce":[57,18,22],
"group__API__Modularized__Scheduler.html#ga862bc72530533cc7eab28294676f5318":[57,18,56],
"group__API__Modularized__Scheduler.html#ga87785b9c9eeb3718d85dc1b2a24fab26":[57,18,29],
"group__API__Modularized__Scheduler.html#ga8efad6df3a5b036619ea5c76fe50a0c5":[57,18,52],
"group__API__Modularized__Scheduler.html#ga90dfe435a72d46bd23ddaffa287833c2":[57,18,40],
"group__API__Modularized__Scheduler.html#ga966aaa040948551bede3ee46c9f8847e":[57,18,18],
"group__API__Modularized__Scheduler.html#ga9bfbf9eb07c5ccc7c77a40ddb37056b8":[57,18,68],
"group__API__Modularized__Scheduler.html#ga9ed484d5707136420880285afe55bd3d":[57,18,44],
"group__API__Modularized__Scheduler.html#gaa207453a69f029b2f3c74bc8b9cffde2":[57,18,70],
"group__API__Modularized__Scheduler.html#gaa838921844068ca3190dca5e2b5a99db":[57,18,13],
"group__API__Modularized__Scheduler.html#gaab8471a2921b0508b9269b08ecfba3b7":[57,18,43],
"group__API__Modularized__Scheduler.html#gab17420484cfb68122d986d1feee91905":[57,18,77],
"group__API__Modularized__Scheduler.html#gab40975877d0c861348ccc96602be2cae":[57,18,26],
"group__API__Modularized__Scheduler.html#gab8540c0e69c3af17c424944af9b3c802":[57,18,28],
"group__API__Modularized__Scheduler.html#gabd7a0274979659050496fcc1c66b7a1c":[57,18,8],
"group__API__Modularized__Scheduler.html#gabf51817bd8f2a32af327d90eb5d126ec":[57,18,55],
"group__API__Modularized__Scheduler.html#gac3ab95326f770ecd208a9949d18ceddf":[57,18,66],
"group__API__Modularized__Scheduler.html#gac863df9e289543dcfd6a0b5e4e60432a":[57,18,23],
"group__API__Modularized__Scheduler.html#gaccfaa23c5e0948fec6be5f71fc69f32c":[57,18,74],
"group__API__Modularized__Scheduler.html#gad06fa143512ae761c452bf0adf685bae":[57,18,54],
"group__API__Modularized__Scheduler.html#gad0e17cdc3def6bd7e9a9a17437969bdb":[57,18,19],
"group__API__Modularized__Scheduler.html#gad76ac70069357b5a3d0ac0a1489016a2":[57,18,69],
"group__API__Modularized__Scheduler.html#gae1aa931285a2b952473fc7def121c5cd":[57,18,16],
"group__API__Modularized__Scheduler.html#gae1ac4bb35944de31705ba297aef1f9a1":[57,18,50],
"group__API__Modularized__Scheduler.html#gae4532cd31d9d069b810bdf52db2e052e":[57,18,15],
"group__API__Modularized__Scheduler.html#gae4fc13eee5dd3528951a5cfea33c03ce":[57,18,12],
"group__API__Modularized__Scheduler.html#gae97d6b25d8143ef2f7b6260c6f550c5c":[57,18,32],
"group__API__Modularized__Scheduler.html#gaec7ff28a32f69a93850a1233a1c2725f":[57,18,35],
"group__API__Modularized__Scheduler.html#gafb485fe5fb1f46c7ce7eb505815f306b":[57,18,9],
"group__API__Modularized__Scheduler.html#gafb5ce04aff2175aed3763a72bf252107":[57,18,20],
"group__API__Modularized__Scheduler.html#gafb683e254b5084a1321a21fde5139b01":[57,18,53],
"group__API__Modularized__Scheduler.html#ggab40975877d0c861348ccc96602be2caea27934b03d9ff6827b318124ff683fb40":[57,18,26,0],
"group__API__Modularized__Scheduler.html#ggab40975877d0c861348ccc96602be2caea40dba09874d6d3a220669e0ccea27da2":[57,18,26,1],
"group__API__Modularized__Scheduler.html#structstarpu__sched__component":[57,18,0],
"group__API__Modularized__Scheduler.html#structstarpu__sched__component__fifo__data":[57,18,2],
"group__API__Modularized__Scheduler.html#structstarpu__sched__component__heteroprio__data":[57,18,5],
"group__API__Modularized__Scheduler.html#structstarpu__sched__component__mct__data":[57,18,4],
"group__API__Modularized__Scheduler.html#structstarpu__sched__component__perfmodel__select__data":[57,18,6],
"group__API__Modularized__Scheduler.html#structstarpu__sched__component__prio__data":[57,18,3],
"group__API__Modularized__Scheduler.html#structstarpu__sched__component__specs":[57,18,7],
"group__API__Modularized__Scheduler.html#structstarpu__sched__tree":[57,18,1],
"group__API__OpenCL__Extensions.html":[57,11],
"group__API__OpenCL__Extensions.html#a685357d9709ece920bf269a917ed8297":[57,11,0,0],
"group__API__OpenCL__Extensions.html#ga002e85a0f6bcd087df54287de5ae5e07":[57,11,30],
"group__API__OpenCL__Extensions.html#ga03f34ac98495afc5d0f268e366f80598":[57,11,15],
"group__API__OpenCL__Extensions.html#ga06f19c27ac5147607acc511d49302321":[57,11,26],
"group__API__OpenCL__Extensions.html#ga160dc78c0f6a90b5aa2200b49c5b4d7b":[57,11,1],
"group__API__OpenCL__Extensions.html#ga1b591248c13dc33e2e9b00ace593405e":[57,11,3],
"group__API__OpenCL__Extensions.html#ga1d06b6c00b15f4fcd8d4c0c998f955ac":[57,11,21],
"group__API__OpenCL__Extensions.html#ga23fa324d87f923f39f05bfdc9d3fe7e9":[57,11,6],
"group__API__OpenCL__Extensions.html#ga2708694c061fd89272b0355bcaac11df":[57,11,27],
"group__API__OpenCL__Extensions.html#ga2bd30ada22e761a6b889f0661b54592f":[57,11,29],
"group__API__OpenCL__Extensions.html#ga3441dd1c6e61717dd81a3a6eb0bf75a8":[57,11,18],
"group__API__OpenCL__Extensions.html#ga6680ed21ce09f073fa0256169f4e4868":[57,11,5],
"group__API__OpenCL__Extensions.html#ga68adf424491ec715e891000fa4a6030d":[57,11,22],
"group__API__OpenCL__Extensions.html#ga7ad0ab374a65417ae3d3a9ceed8f24c4":[57,11,7],
"group__API__OpenCL__Extensions.html#ga7dd3784262c0be223394bc8c2fe81935":[57,11,13],
"group__API__OpenCL__Extensions.html#ga7f8e1507dec24eaa7427923bbacb873f":[57,11,24],
"group__API__OpenCL__Extensions.html#ga80f968f210417eb9fbf2bfe82e1953a9":[57,11,12],
"group__API__OpenCL__Extensions.html#ga8318641373e06a2a635cb3ab377c5994":[57,11,9],
"group__API__OpenCL__Extensions.html#ga84a524eaac758722f083ee129a19a567":[57,11,8],
"group__API__OpenCL__Extensions.html#ga893f462bfed53eff3a54f341488db7ad":[57,11,17],
"group__API__OpenCL__Extensions.html#ga95184b2188d67976e00bcb4637ac1933":[57,11,31],
"group__API__OpenCL__Extensions.html#ga9768e086b947961c9db5199e676f05db":[57,11,19],
"group__API__OpenCL__Extensions.html#ga9a1331f26cc54a1f5406770f68b95d29":[57,11,28],
"group__API__OpenCL__Extensions.html#ga9e0073e4c839eec6096f6eeca21d7e36":[57,11,25],
"group__API__OpenCL__Extensions.html#gaa38e7cb3231ed30303e50f46c8f6e39c":[57,11,20],
"group__API__OpenCL__Extensions.html#gab43c1f30361aaa72ca98a9a9fdec792b":[57,11,11],
"group__API__OpenCL__Extensions.html#gababf3ee0552f34c89fdc8ebdec116dbf":[57,11,2],
"group__API__OpenCL__Extensions.html#gac543428352d04b3ff8f735cfc71c3b99":[57,11,16],
"group__API__OpenCL__Extensions.html#gad18d6a0dfbfadcb0fe0b2be6294aa87d":[57,11,10],
"group__API__OpenCL__Extensions.html#gadc4689d1ad238ba0b296e205e3bb6317":[57,11,14],
"group__API__OpenCL__Extensions.html#gae023af317c4040f926d2c50a8f96b5d2":[57,11,4],
"group__API__OpenCL__Extensions.html#gaeaabc8e5d90531a21a8307c06c659984":[57,11,23],
"group__API__OpenCL__Extensions.html#structstarpu__opencl__program":[57,11,0],
"group__API__OpenMP__Runtime__Support.html":[57,17],
"group__API__OpenMP__Runtime__Support.html#a294032947604cf227abad87b30a08c27":[57,17,2,6],
"group__API__OpenMP__Runtime__Support.html#a4f4e595f12101bbace47d4748d6d3e3b":[57,17,3,0],
"group__API__OpenMP__Runtime__Support.html#a594489c9f845922d685046c25f5540e8":[57,17,3,3],
"group__API__OpenMP__Runtime__Support.html#a6e3c542eac204dd67f343427c8a0a17c":[57,17,3,8],
"group__API__OpenMP__Runtime__Support.html#a782139c5c2358477059af82135f76cc2":[57,17,3,9],
"group__API__OpenMP__Runtime__Support.html#a983c8209cef872e2798c2fee32012195":[57,17,2,0],
"group__API__OpenMP__Runtime__Support.html#a9886b8bade17a2e0c32bb2b36cb6c392":[57,17,3,1],
"group__API__OpenMP__Runtime__Support.html#ab4a1aab4aa59767666547ff12a5374a2":[57,17,1,0],
"group__API__OpenMP__Runtime__Support.html#ab804599e2d1ce232830954dbdf3ed886":[57,17,2,3],
"group__API__OpenMP__Runtime__Support.html#abb648c16a9ec65f2834cf05994b33df2":[57,17,3,7],
"group__API__OpenMP__Runtime__Support.html#acd7ec3b07eded637a0c9de5df3192e87":[57,17,2,2],
"group__API__OpenMP__Runtime__Support.html#acf0b820ff6649f9290dbfa3d270d8cec":[57,17,2,1],
"group__API__OpenMP__Runtime__Support.html#acfc22eabce32bfa73fd5020f275c3cf2":[57,17,0,0],
"group__API__OpenMP__Runtime__Support.html#ad64a8be227ee0a2c4ea8fa2eca3d20c0":[57,17,3,4],
"group__API__OpenMP__Runtime__Support.html#ad7d88a7759aade7ae379a88eb737993b":[57,17,3,2],
"group__API__OpenMP__Runtime__Support.html#ae97da9038c9a034dc8734ae4c34ebc21":[57,17,3,6],
"group__API__OpenMP__Runtime__Support.html#aea66f9b4181afb2e4b4c799a09d8a4f0":[57,17,2,4],
"group__API__OpenMP__Runtime__Support.html#aecf5779017beb31e13424202f9dc013b":[57,17,2,5],
"group__API__OpenMP__Runtime__Support.html#afa30d3c752ab9665112df925a39cb4ab":[57,17,3,5],
"group__API__OpenMP__Runtime__Support.html#ga05ecbf96c69f19525730f46d49d92937":[57,17,50],
"group__API__OpenMP__Runtime__Support.html#ga0a2d26b924681a81e92562edf7fa6742":[57,17,26],
"group__API__OpenMP__Runtime__Support.html#ga0a86f6a9d780b564dae9b9a71cfe5e19":[57,17,4],
"group__API__OpenMP__Runtime__Support.html#ga0ae276c0004d0e148e5b85c5262d4f1b":[57,17,38],
"group__API__OpenMP__Runtime__Support.html#ga0fb5be52e8f7630a4f24c2e844a22519":[57,17,79],
"group__API__OpenMP__Runtime__Support.html#ga1080ae6a620b2c40c71311df32ab44d4":[57,17,29],
"group__API__OpenMP__Runtime__Support.html#ga1118d277474ac2dc1a22bf6ef4c59fa9":[57,17,46],
"group__API__OpenMP__Runtime__Support.html#ga13f5e9162e12620fb814627d6eb5e1e8":[57,17,39],
"group__API__OpenMP__Runtime__Support.html#ga1a6d1009b6ff1f68617ade03554d03f3":[57,17,55],
"group__API__OpenMP__Runtime__Support.html#ga1b1d7573040775370ffd49b7accad0f2":[57,17,68]
};
